nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Flshcr4

Struct Flshcr4 

#[repr(transparent)]
pub struct Flshcr4(pub u32);
Flash Control Register 4

Tuple Fields

0: u32

Implementations

Source

impl Flshcr4

pub const fn wmopt1(&self) -> bool

Write mask option bit 1. This option bit could be used to remove AHB write burst start address alignment limitation.

pub const fn set_wmopt1(&mut self, val: bool)

Write mask option bit 1. This option bit could be used to remove AHB write burst start address alignment limitation.

pub const fn wmena(&self) -> Wmena

Write mask enable bit for flash device on port A. When write mask function is needed for memory device on port A, this bit must be set.

pub const fn set_wmena(&mut self, val: Wmena)

Write mask enable bit for flash device on port A. When write mask function is needed for memory device on port A, this bit must be set.

pub const fn wmenb(&self) -> Wmenb

Write mask enable bit for flash device on port B. When write mask function is needed for memory device on port B, this bit must be set.

pub const fn set_wmenb(&mut self, val: Wmenb)

Write mask enable bit for flash device on port B. When write mask function is needed for memory device on port B, this bit must be set.