nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Intr

Struct Intr 

#[repr(transparent)]
pub struct Intr(pub u32);
Interrupt Register

Tuple Fields

0: u32

Implementations

Source

impl Intr

pub const fn ipcmddone(&self) -> bool

IP triggered Command Sequences Execution finished interrupt. This interrupt is also generated when there is IPCMDGE or IPCMDERR interrupt generated.

pub const fn set_ipcmddone(&mut self, val: bool)

IP triggered Command Sequences Execution finished interrupt. This interrupt is also generated when there is IPCMDGE or IPCMDERR interrupt generated.

pub const fn ipcmdge(&self) -> bool

IP triggered Command Sequences Grant Timeout interrupt.

pub const fn set_ipcmdge(&mut self, val: bool)

IP triggered Command Sequences Grant Timeout interrupt.

pub const fn ahbcmdge(&self) -> bool

AHB triggered Command Sequences Grant Timeout interrupt.

pub const fn set_ahbcmdge(&mut self, val: bool)

AHB triggered Command Sequences Grant Timeout interrupt.

pub const fn ipcmderr(&self) -> bool

IP triggered Command Sequences Error Detected interrupt. When an error detected for IP command, this command will be ignored and not executed at all.

pub const fn set_ipcmderr(&mut self, val: bool)

IP triggered Command Sequences Error Detected interrupt. When an error detected for IP command, this command will be ignored and not executed at all.

pub const fn ahbcmderr(&self) -> bool

AHB triggered Command Sequences Error Detected interrupt. When an error detected for AHB command, this command will be ignored and not executed at all.

pub const fn set_ahbcmderr(&mut self, val: bool)

AHB triggered Command Sequences Error Detected interrupt. When an error detected for AHB command, this command will be ignored and not executed at all.

pub const fn iprxwa(&self) -> bool

IP RX FIFO watermark available interrupt.

pub const fn set_iprxwa(&mut self, val: bool)

IP RX FIFO watermark available interrupt.

pub const fn iptxwe(&self) -> bool

IP TX FIFO watermark empty interrupt.

pub const fn set_iptxwe(&mut self, val: bool)

IP TX FIFO watermark empty interrupt.

pub const fn sckstopbyrd(&self) -> bool

SCLK is stopped during command sequence because Async RX FIFO full interrupt.

pub const fn set_sckstopbyrd(&mut self, val: bool)

SCLK is stopped during command sequence because Async RX FIFO full interrupt.

pub const fn sckstopbywr(&self) -> bool

SCLK is stopped during command sequence because Async TX FIFO empty interrupt.

pub const fn set_sckstopbywr(&mut self, val: bool)

SCLK is stopped during command sequence because Async TX FIFO empty interrupt.

pub const fn ahbbuserror(&self) -> bool

AHB Bus timeout or AHB bus illegal access Flash during OTFAD key blob processing interrupt.

pub const fn set_ahbbuserror(&mut self, val: bool)

AHB Bus timeout or AHB bus illegal access Flash during OTFAD key blob processing interrupt.

pub const fn seqtimeout(&self) -> bool

Sequence execution timeout interrupt.

pub const fn set_seqtimeout(&mut self, val: bool)

Sequence execution timeout interrupt.

pub const fn keydone(&self) -> bool

OTFAD key blob processing done interrupt.

pub const fn set_keydone(&mut self, val: bool)

OTFAD key blob processing done interrupt.

pub const fn keyerror(&self) -> bool

OTFAD key blob processing error interrupt.

pub const fn set_keyerror(&mut self, val: bool)

OTFAD key blob processing error interrupt.